@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-d6317c3095bd2c74629cf97c7fc2102e
-key: yesod_K2kbtomDZI5J4lsL4BSRUZ
+id: yesod-1.4.2-e3455ef9cbbd53ee4ffc7045c5d026cf
+key: yesod_0b3hheIb5Ve4uIZ3iHTfNA
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,19 +21,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-K2kbtomDZI5J4lsL4BSRUZ
+hs-libraries: HSyesod-1.4.2-0b3hheIb5Ve4uIZ3iHTfNA
 depends:
     aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
     blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-extra-1.1.9.2-79e9518024a2df5c3adcf7d7df9fbea5
+    conduit-extra-1.1.9.2-aa4a80a63306500e6d6a1edce4badfdd
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.17-d3b65fae3959e41c01434c1c220af3fd
+    monad-logger-0.3.18-2bfbe07c1c1cdc537fa81b345cec7330
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
     shakespeare-2.0.7-3d8247ff57d7f10558308bd73d118ae2
@@ -44,14 +44,14 @@ depends:
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
     wai-3.2.0-ef5213f36cb00369a3d68c2dd00424b9
-    wai-extra-3.0.13.1-2dd6d778b5d3c8057ac149701ac5c371
+    wai-extra-3.0.13.1-754076fbe6d9ad0271640500660355fd
     wai-logger-2.2.4.1-78754ae80b1823d94a638e54c94b2c6e
-    warp-3.2.1-8f9aad771e0c137389da779f459b244d
-    yaml-0.8.15.3-3d6bb92af78b0dac755a8e256ace903e
-    yesod-auth-1.4.12-8d535892f623fa948d936e886d3bdb4c
-    yesod-core-1.4.19-516d05f0f7a24f16b48a3d78a1b5e378
-    yesod-form-1.4.6-4e51451ad8a0ff5cee562f45fede6545
-    yesod-persistent-1.4.0.3-e292066aa899804c642be44b1d89205f
+    warp-3.2.1-184b585d1fe25e67a905eacad9ccd211
+    yaml-0.8.15.3-09a15b752fd0338a3f112f0a1d663798
+    yesod-auth-1.4.12-cc89ddaa1d8ceca602ee7d4484044559
+    yesod-core-1.4.19-97e13dc735e6c4c26d8664b1b0881662
+    yesod-form-1.4.6-f33925874fe42e8068b104bdcab5984d
+    yesod-persistent-1.4.0.3-b0d59ef575a9f5abbc9cd66ae1d954b9
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
